@@ -32,11 +32,11 @@
 #
 ################################################################################
 """
+import html
 
 ident = '$Id: SOAPBuilder.py 1498 2010-03-12 02:13:19Z pooryorick $'
 from .version import __version__
 
-import cgi
 from wstools.XMLname import toXMLname, fromXMLname
 
 # SOAPpy-py3 modules
@@ -313,7 +313,7 @@ class SOAPBuilder:
         try: data = obj._marshalData()
         except:
             if (obj_type != "string"): # strings are already encoded
-                data = cgi.escape(str(obj))
+                data = html.escape(str(obj))
             else:
                 data = obj
 
@@ -373,7 +373,7 @@ class SOAPBuilder:
         try: data = obj._marshalData()
         except: data = obj
 
-        self.out.append(self.dumper(None, "string", cgi.escape(data), tag,
+        self.out.append(self.dumper(None, "string", html.escape(data), tag,
                                     typed, ns_map, self.genroot(ns_map), id))
 
     dump_str = dump_string # For Python 2.2+
